@@ -7,6 +7,7 @@
 ## 2019-11-10 summary.traps etc. moved to file summary.traps.R
 ## 2020-08-27 radical revamp of occasion, trap and animalID functions, 
 ##            with unified code
+## 2020-11-07 alive() rewritten to match preceding
 ###############################################################################
 
 # Generic methods for extracting attributes etc
@@ -446,7 +447,7 @@ signalmatrix <- function (object, noise = FALSE, recodezero = FALSE,
     }
 }
 
-alive <- function (object) {
+aliveold <- function (object) {
     if (!inherits(object, 'capthist'))
         stop ("requires 'capthist' object")
     if (ms(object)) {
@@ -469,7 +470,9 @@ captmatrix <- function (object) {
   # form a matrix with indices of animalID, occasion and detector
     # number of rows is product of these dimensions
     if (length(dim(object)) < 3 ) {
-        stop ("3-D capthist required by animalID(), occasion() and trap()")
+        # stop ("3-D capthist required by animalID(), occasion() and trap()")
+        if (length(dim(object))==2)
+            object <- array(object, dim=c(dim(object),1))  ## 2020-12-08
     }
     if (nrow(object)<1) {
         stop ("captmatrix expects at least one row in capthist")      
@@ -506,6 +509,26 @@ occasion <- function (object) {
     }
 }
 
+alive <- function (object) {
+    # revised 2020-11-07
+    if (!inherits(object, 'capthist'))
+        stop ("requires 'capthist' object")
+    if (ms(object)) {
+        lapply(object, alive)
+    }
+    else {
+        if (nrow(object) == 0) {
+            out <- NULL
+        }
+        else {
+            tmp <- captmatrix(object)
+            temp <- sign(object[tmp[,1:3]]) > 0
+            out <- rep(temp, tmp[,4])
+        }
+        as.logical(out)
+    }
+}
+
 trap <- function (object, names = TRUE) {
   if (!inherits(object, 'capthist'))
     stop ("requires 'capthist' object")
