@@ -4,6 +4,7 @@
 ## 2012-12-18 binary.usage
 ## 2015-05-04 multi-file input
 ## 2015-10-12 markocc
+## 2020-08-26 allow usage and covariates with data and xls input
 
 ## Read detector locations from text file in DENSITY format
 ############################################################################################
@@ -19,7 +20,7 @@ renamepolyrows <- function (tr) {
 }
 
 read.traps <- function (file = NULL, data = NULL, detector = 'multi', covnames = NULL,
-                        binary.usage = TRUE, markocc = NULL, trapID = NULL, ...)
+    binary.usage = TRUE, markocc = NULL, trapID = NULL, ...)
     ## possibly add sortrows argument, but risk breaking covariates, polygon etc.
 {
     
@@ -41,12 +42,12 @@ read.traps <- function (file = NULL, data = NULL, detector = 'multi', covnames =
     if (length(file) > 1) {
         if (is.null(markocc))
             out <- mapply(read.traps, file=file, MoreArgs = list(detector = detector,
-                                                                 covnames = covnames, binary.usage = binary.usage, ...), SIMPLIFY = FALSE)
+                covnames = covnames, binary.usage = binary.usage, ...), SIMPLIFY = FALSE)
         else {
             if (!inherits(markocc, 'list'))
                 markocc <- list(markocc)
             out <- mapply(read.traps, file=file, markocc = markocc, MoreArgs = list(detector = detector,
-                                                                                    covnames = covnames, binary.usage = binary.usage, ...), SIMPLIFY = FALSE)
+                covnames = covnames, binary.usage = binary.usage, ...), SIMPLIFY = FALSE)
         }
         class (out) <- c('traps', 'list')
         out
@@ -79,7 +80,7 @@ read.traps <- function (file = NULL, data = NULL, detector = 'multi', covnames =
                 }
                 rownames(data) <- data[,trapID]
                 out <- read.traps(data = data, markocc = markocc, detector = detector,
-                           covnames = covnames, binary.usage = binary.usage)
+                    covnames = covnames, binary.usage = binary.usage)
                 return(out)
             }
             else {
@@ -90,7 +91,7 @@ read.traps <- function (file = NULL, data = NULL, detector = 'multi', covnames =
                 else colcl <- c('character',NA,NA,'character')
                 if (all(detector %in% c('polygon', 'polygonX'))) {
                     temp <- read.table (file, row.names=NULL, as.is=T,
-                                        colClasses = colcl, ...)
+                        colClasses = colcl, ...)
                     names(temp)[1:3] <- c('polyID','x','y')
                     
                     tempID <- levels(factor(temp$polyID))
@@ -105,7 +106,7 @@ read.traps <- function (file = NULL, data = NULL, detector = 'multi', covnames =
                 }
                 else if (all(detector %in% c('transect', 'transectX'))) {
                     temp <- read.table (file, row.names=NULL, as.is=T,
-                                        colClasses = colcl, ...)
+                        colClasses = colcl, ...)
                     names(temp)[1:3] <- c('transectID','x','y')
                     tempID <- levels(factor(temp$transectID))
                     tempindex <- match (tempID, as.character(temp$transectID))
@@ -116,7 +117,7 @@ read.traps <- function (file = NULL, data = NULL, detector = 'multi', covnames =
                 }
                 else {
                     temp <- read.table (file, row.names = 1, as.is = T,
-                                        colClasses = colcl, ...)
+                        colClasses = colcl, ...)
                     traps <- temp[,1:2,drop=FALSE]
                     class(traps)    <- c('traps', 'data.frame')
                 }
@@ -129,7 +130,7 @@ read.traps <- function (file = NULL, data = NULL, detector = 'multi', covnames =
             if ('polyID' %in% names(data)) {
                 temp <- split (data[,c('x','y','polyID'),drop=FALSE], data$polyID)
                 data <- as.data.frame(abind(lapply(temp, closepoly), along = 1),
-                                      force.array = FALSE)
+                    force.array = FALSE)
             }
             else {
                 if (!is.null(trapID))
@@ -146,86 +147,95 @@ read.traps <- function (file = NULL, data = NULL, detector = 'multi', covnames =
         traps <- renamepolyrows(traps)
         usage(traps)      <- NULL
         covariates(traps) <- NULL
-        if (!is.null(file)) {
-            if (ncol(temp)>2) {
-                if (ncol(temp)>3)
-                    temp2 <- apply(temp[,3:ncol(temp),drop=FALSE], 1, paste, collapse=' ')
-                else
-                    temp2 <- temp[,3]
-                splitfield <- matrix(unlist(strsplit(as.character(temp2),'/')),
-                                     byrow = T, nrow = length(temp2))                            # before '/'
-                
-                if (binary.usage) {
-                    used <- gsub(' ','', splitfield[,1,drop=FALSE])                 # remove blanks
-                    used <- gsub('//t','', used)                                    # remove tabs
-                    used <- gsub(',','', used)                                      # remove commas
-                    nocc <- max(nchar(used))
-                    if (nocc>0) {
-                        if (all(detector %in% .localstuff$polydetectors)) {
-                            used <- used[tempindex]
-                            nocc <- max(nchar(used))   ## recompute
-                            
-                            if (any(nchar(used) != nocc))
-                                stop ("'usage' fields suggest varying number ",
-                                      "of occasions")
-                            usge <- (matrix(unlist(strsplit(used,split='')),
-                                            byrow = TRUE, ncol = nocc)>0) * 1
-                            
-                            dimnames(usge) <- list( tempID, 1:nocc)
-                            usage(traps) <- usge
-                        }
-                        else {
-                            if (any(nchar(used) != nocc))
-                                stop ("'usage' fields suggest varying number ",
-                                      "of occasions")
-                            usge <- (matrix(unlist(strsplit(used,split='')),
-                                            byrow = TRUE, ncol = nocc)>0) * 1
-                            dimnames(usge) <- list(dimnames(traps)[[1]], 1:nocc)
-                            usage(traps) <- usge
-                        }
+        
+        ## 2020-08-26
+        temp2 <- NULL
+        if (!is.null(file) && ncol(temp)>2) {
+            if (ncol(temp)>3)
+                temp2 <- apply(temp[,3:ncol(temp),drop=FALSE], 1, paste, collapse=' ')
+            else
+                temp2 <- temp[,3]
+        }
+        else if (!is.null(data) && ncol(data)>3) {
+            temp2 <- apply(data[,-(1:3), drop = FALSE],1,paste, collapse = ' ')
+        }
+        if  (!is.null(temp2)) {               
+            
+            splitfield <- matrix(unlist(strsplit(as.character(temp2),'/')),
+                byrow = T, nrow = length(temp2))                            # before '/'
+            
+            if (binary.usage) {
+                used <- gsub(' ','', splitfield[,1,drop=FALSE])                 # remove blanks
+                used <- gsub('//t','', used)                                    # remove tabs
+                used <- gsub(',','', used)                                      # remove commas
+                nocc <- max(nchar(used))
+                if (nocc>0) {
+                    if (all(detector %in% .localstuff$polydetectors)) {
+                        
+                        stop("usage input not available for polygon detectors in 4.3.1")
+                        used <- used[tempindex]
+                        nocc <- max(nchar(used))   ## recompute
+                        
+                        if (any(nchar(used) != nocc))
+                            stop ("'usage' fields suggest varying number ",
+                                "of occasions")
+                        usge <- (matrix(unlist(strsplit(used,split='')),
+                            byrow = TRUE, ncol = nocc)>0) * 1
+                        
+                        dimnames(usge) <- list( tempID, 1:nocc)
+                        usage(traps) <- usge
                     }
+                    else {
+                        if (any(nchar(used) != nocc))
+                            stop ("'usage' fields suggest varying number ",
+                                "of occasions")
+                        usge <- (matrix(unlist(strsplit(used,split='')),
+                            byrow = TRUE, ncol = nocc)>0) * 1
+                        dimnames(usge) <- list(dimnames(traps)[[1]], 1:nocc)
+                        usage(traps) <- usge
+                    }
+                }
+            }
+            else {
+                ## tentative 2012-12-18
+                tempcon <- textConnection(splitfield[,1, drop = FALSE])
+                usge <- as.matrix(read.table(tempcon))
+                close(tempcon)
+                nocc <- ncol(usge)
+                if (all(detector %in% .localstuff$polydetectors)) {
+                    ## 2014-08-23 bug fix
+                    ## usge <- usge[tempindex,]
+                    usge <- usge[tempindex,,drop = FALSE]
+                    dimnames(usge) <- list( tempID, 1:nocc)
                 }
                 else {
-                    ## tentative 2012-12-18
-                    tempcon <- textConnection(splitfield[,1, drop = FALSE])
-                    usge <- as.matrix(read.table(tempcon))
-                    close(tempcon)
-                    nocc <- ncol(usge)
-                    if (all(detector %in% .localstuff$polydetectors)) {
-                        ## 2014-08-23 bug fix
-                        ## usge <- usge[tempindex,]
-                        usge <- usge[tempindex,,drop = FALSE]
-                        dimnames(usge) <- list( tempID, 1:nocc)
-                    }
-                    else {
-                        dimnames(usge) <- list(dimnames(traps)[[1]], 1:nocc)
-                    }
-                    usage(traps) <- usge
+                    dimnames(usge) <- list(dimnames(traps)[[1]], 1:nocc)
                 }
-                if (length(detector)>1 & length(detector) != nocc)
-                    stop ("differing number of occasions in detector and usage")
+                usage(traps) <- usge
+            }
+            if (length(detector)>1 & length(detector) != nocc)
+                stop ("differing number of occasions in detector and usage")
+            if (ncol(splitfield)>1) {
+                if (all(detector %in% .localstuff$polydetectors)) {
+                    splitfield <- splitfield[tempindex,, drop = FALSE]
+                    rownam <- tempID
+                }
+                else {
+                    rownam <- rownames(traps)
+                }
+                tempcon <- textConnection(splitfield[,2, drop = FALSE])
+                covariates(traps) <- data.frame(read.table(tempcon))
+                rownames(covariates(traps)) <- rownam
+                close(tempcon)
                 
-                if (ncol(splitfield)>1) {
-                    if (all(detector %in% .localstuff$polydetectors)) {
-                        splitfield <- splitfield[tempindex,, drop = FALSE]
-                        rownam <- tempID
-                    }
-                    else {
-                        rownam <- rownames(traps)
-                    }
-                    tempcon <- textConnection(splitfield[,2, drop = FALSE])
-                    covariates(traps) <- data.frame(read.table(tempcon))
-                    rownames(covariates(traps)) <- rownam
-                    close(tempcon)
-                    
-                    if (!is.null(covnames)) {
-                        ncc <- ncol(covariates(traps))
-                        if (length(covnames) != ncc)
-                            stop ("number of covariate names does ",
-                                  "not match number of columns ", ncc )
-                        names (covariates(traps)) <- covnames
-                    }
+                if (!is.null(covnames)) {
+                    ncc <- ncol(covariates(traps))
+                    if (length(covnames) != ncc)
+                        stop ("number of covariate names does ",
+                            "not match number of columns ", ncc )
+                    names (covariates(traps)) <- covnames
                 }
+                
             }
         }
         ux <- unique(traps$x)
