@@ -21,8 +21,8 @@
 ## e.g. Roger Peng https://stat.ethz.ch/pipermail/r-devel/2009-March/052883.html
 
 .localstuff <- new.env()
-.localstuff$packageType <- ' pre-release'
-## .localstuff$packageType <- ''
+##.localstuff$packageType <- ' pre-release'
+.localstuff$packageType <- ''
 .localstuff$validdetectors <- c('single','multi','proximity','count', 
     'polygonX', 'transectX', 'signal', 'polygon', 'transect', 
     'capped', 'null','null','null','null', 'telemetry', 'signalnoise')
@@ -592,8 +592,6 @@ pointsInPolygon <- function (xy, poly, logical = TRUE) {
         mask <- round(mask/sp) + 1
         xy <- sweep(xy, MARGIN = 2, FUN = '+', STATS = c(-minx, -miny))
         xy <- round(xy/sp) + 1
-        ## 2013-03-06 tweak
-        ## xy[xy<0] <- NA
         xy[xy<=0] <- NA
         xy[,1][xy[,1]>max(mask$x, na.rm = TRUE)] <- NA
         xy[,2][xy[,2]>max(mask$y, na.rm = TRUE)] <- NA
@@ -809,7 +807,8 @@ distancetotrap <- function (X, traps) {
     detecttype <- ifelse (is.null(detecttype), "", detecttype)
     
     ## 2020-01-08
-    if (all(detecttype %in% c('polygon', 'polygonX')) && requireNamespace('rgeos')) {
+    if (all(detecttype %in% c('polygon', 'polygonX')) && 
+            requireNamespace('rgeos', quietly = TRUE)) {
         trps <- split(traps, polyID(traps))
         polys <- lapply(trps, boundarytoSP)
         xy <- sp::SpatialPoints(X)
@@ -820,7 +819,7 @@ distancetotrap <- function (X, traps) {
     }
         
     if (inherits(traps, 'SpatialPolygons')) {
-        if (requireNamespace('rgeos')) {
+        if (requireNamespace('rgeos', quietly = TRUE)) {
             xy <- sp::SpatialPoints(X)
             d <- rgeos::gDistance(spgeom1 = xy, spgeom2 = traps, byid = TRUE)
             return (d)
@@ -1626,7 +1625,7 @@ nedist <- function (xy1, xy2, mask, inf = Inf, ...) {
     defaultargs <- list(transitionFunction = mean, directions = 16)
     args <- replace(defaultargs, names(newargs), newargs)
     args$x <- raster(mask, values = noneuc)
-    if (requireNamespace('gdistance')) {    ## 2015-01-23
+    if (requireNamespace('gdistance', quietly = TRUE)) {    ## 2015-01-23
         tr <- do.call(gdistance::transition, args)
         tr <- gdistance::geoCorrection(tr, type = "c", multpl = FALSE)
         out <- gdistance::costDistance(tr, as.matrix(xy1), as.matrix(xy2))
